comp.dend <-
function (x = dend.topo(hclust(dist(matrix(c(1:50)/10, nrow = 10, 
    ncol = 5, dimnames = list(LETTERS[1:10], c(1:5)))))), y = dend.topo(hclust(dist(matrix(c(1:50)/9, 
    nrow = 10, ncol = 5, dimnames = list(LETTERS[1:10], c(1:5)))))), compare.groups = FALSE) 
{
	# Version edited 7_NewCompDend; Wed Sep  4 08:05:36 2024
    if (class(x) != "list") 
        stop("x must be the output of dend.topo()!")
    if (class(y) != "list") 
        stop("y must be the output of dend.topo()!")
    if (prod(names(x)[1:2] == c("original", "clusters")) != 1) 
        stop("x must be the output of dend.topo()!")
    if (prod(names(y)[1:2] == c("original", "clusters")) != 1) 
        stop("y must be the output of dend.topo()!")
    if (1 * setequal(x$clusters[[nrow(x$original)]], y$clusters[[nrow(y$original)]]) != 
        1) 
        stop("x & y are not comparable!")
    # The number of clusters in both, without taking into account the last one
    # which is the largest and thus include the whole enchilada.
    n.r.res <- length(x$clusters) - 1 
    # Prepare some results for topo.summary
    temp.l.x <- table(unlist(lapply(x$clusters, length)[1:n.r.res]))
    temp.l.y <- table(unlist(lapply(y$clusters, length)[1:n.r.res]))
    
    the.call <- match.call()
    obj.names <- as.character(the.call)[2:3]
    if (is.na(obj.names[1])) 
        obj.names[1] <- "x"
    if (is.na(obj.names[2])) 
        obj.names[2] <- "y"
    hx <- x$original$height
    hy <- y$original$height
    # Statistics for height of all clusters
    height.stats <- matrix(NA, nrow=2, ncol=6, dimnames=list(c("All", "Identical"), c("n", "Mean.x", "Mean.y", "S.x", "S.y", "p.value")))
       height.stats[1, ] <- c(length(hx), mean(hx), mean(hy), sd(hx), sd(hy), t.test(hx, hy)$p.value) 

# Here begin changes.
	temp.main <- analyze2sets(x=x$clusters, y=y$clusters,  only.identical=TRUE)
	# If the number of rows of temp.main is less than 2 stop.
	if(nrow(temp.main) < 2) stop("Sorry, there are not common clusters in the two dendrograms.")
	# Note that n.r.res is the number of clusters in both dendrograms
	n.ident <- nrow(temp.main) - 1 # Because the complete will be in both
	temp.main <- temp.main[c(1:n.ident),]
	names(temp.main)[3] <- "class" # As previously
	# Add new variables
	temp.main$id <- c(1:n.ident)
	temp.main$height.x <- NA
	temp.main$height.y <- NA
	temp.main <- temp.main[,c(5, 3, 1, 2, 6, 7, 4)] # re-order columns
	attributes(temp.main)$row.names <- c(1:n.ident)

	# Fill heights
	for(i in 1:n.ident){
		temp.main$height.x[i] <- hx[temp.main$id.x[i]]
		temp.main$height.y[i] <- hy[temp.main$id.y[i]] 
	}
	
	temp.tab.ide <- table(temp.main$class)
	# For topo.summary; Conjoint: temp.l.x, temp.l.y, temp.tab.ide
	temp.nam.col <- sort(union(as.integer(names(temp.l.x)), as.integer(names(temp.l.y))))
	temp.n.col <- length(temp.nam.col)
	topo.summary <- matrix(0, nrow=4, ncol=temp.n.col, dimnames=list(c("n.in.x", "n.in.y", "n.ident", "p.ident"), temp.nam.col))
	# Note: temp.nam.col is integer
	# Now fill topo.summary
	for(i in 1:length(temp.l.x)){ # for temp.l.x
		temp.wc <- c(1:temp.n.col)[temp.nam.col==names(temp.l.x)[i]]
		topo.summary[1, temp.wc] <- temp.l.x[i]
	}
	for(i in 1:length(temp.l.y)){ # for temp.l.y
		temp.wc <- c(1:temp.n.col)[temp.nam.col==names(temp.l.y)[i]]
		topo.summary[2, temp.wc] <- temp.l.y[i]
	}
	for(i in 1:length(temp.tab.ide)){ # temp.tab.ide
		temp.wc <- c(1:temp.n.col)[temp.nam.col==names(temp.tab.ide)[i]]
		topo.summary[3, temp.wc] <- temp.tab.ide[i]
	}
	# Obtain the proportion of identities
	topo.summary[4, ] <- topo.summary[3, ] / apply(topo.summary[1:2, ], 2, max)
	# Now obtain the weighted likeness, w.likeness, as the
	# weighted average of topo.summary[4, ] per temp.nam.col
	w.likeness <-  mean(topo.summary[4, ])
	
	# temp.main is ready
	# Make the row with statistics of height in identical clusters temp.main height.x height.y
	height.stats[2, ] <- c(nrow(temp.main), mean(temp.main$height.x), mean(temp.main$height.y), sd(temp.main$height.x), sd(temp.main$height.y), t.test(temp.main$height.x, temp.main$height.y, paired = TRUE)$p.value)
	
	# Now the baisic or summary of results.
	basic <- c(n.r.res, n.ident, n.ident/n.r.res, w.likeness)
	names(basic) <- c("n.comp", "n.ident", "likeness", "w.likeness")
	if(compare.groups == FALSE){
		final.res <- list(basic, topo.summary, temp.main, height.stats, obj.names, the.call)
		names(final.res) <- c("basic", "topo.summary", "identical", "height.stats", "objects", "call")
	} else {
		final.res <- list(basic, topo.summary, temp.main, height.stats, analyze2sets(x=x$clusters, y=y$clusters), obj.names, the.call)
		names(final.res) <- c("basic", "topo.summary", "identical", "height.stats", "clusters.comparison", "objects", "call")
	}	
    final.res
}
