\name{DendroLikeness-package}
\alias{DendroLikeness-package}
\alias{DendroLikeness}
\docType{package}
\title{
\packageTitle{DendroLikeness}
}
\description{
\packageDescription{DendroLikeness}
}
\details{

The DESCRIPTION file:
\packageDESCRIPTION{DendroLikeness}
\packageIndices{DendroLikeness}
In R you can obtain a matrix of distances between a set of rows using the function \code{dist()}. Then, a bifurcating dendrogram can be obtained from that distance matrix by using the function \code{hclust()}. Distinct alternatives exist to estimate the distance matrix, and then different clustering methods can be employed to obtain a bifurcating dendrogram with \code{hclust()}. This can result in different dendrograms for the same set of rows. To visually detect the differences between any pair of those dendrograms can be complex when the number of rows in the original data is moderately large. 

This package gives a two steps solution to the problem of comparing the topology of two dendrograms obtained from the same set of rows. First, function \code{dend.topo()} gives a description of the topology of a dendrogram and, second, the function \code{comp.dend()} performs the comparison of the topologies of two dendrograms, summarizing their likeness and giving an explicit list of the clusters that are shared by the two graphs.
}
\author{
\packageAuthor{DendroLikeness}

Maintainer: \packageMaintainer{DendroLikeness}
}
\references{
Everitt, B. (1974). Cluster Analysis. London: Heinemann Educ. Books.
}
\keyword{ package }
\seealso{
\code{\link{analyze.set}}, \code{\link{analyze2sets}}, \code{\link{dend.topo}}, \code{\link{comp.dend}}, \code{\link{test.set}}
}
\examples{
# Obtain a dendrogram for 10 objects using a dummy distance matrix
# and the "complete" method:
temp.den1 <- hclust(dist(matrix(c(1:50)/10, nrow = 10, ncol = 5, 
dimnames = list(LETTERS[1:10], c(1:5)))), method="complete")
# Optionally you could plot the dendrogram using "plot(temp.den1)"

# Obtain another dendrogram for the same 10 objects but with a different
# distance matrix and method ="average":
temp.den2 <- hclust(dist(matrix(c(c(1:25), c(25:1))/10, nrow = 10, 
ncol = 5, dimnames = list(LETTERS[1:10], c(1:5)))), method="average")
# Optionally you could plot the dendrogram using "plot(temp.den2)"

# Obtain the topology of the first dendrogram
temp.to1 <- dend.topo(temp.den1)
# You could examine the original values of the groups in
temp.to1$original
# And also the clusters (groups) formed in
temp.to1$clusters

# Obtain the topology of the second dendrogram
temp.to2 <- dend.topo(temp.den2)
# You could examine the original values of the groups in
temp.to2$original
# And also the clusters (groups) formed in
temp.to2$clusters

# Now you can compare the two dendrograms with
temp.com1vs2 <- comp.dend(temp.to1, temp.to2)
# This result is a list with components:
names(temp.com1vs2)

# And see some of the components:
temp.com1vs2$basic # The basic results
temp.com1vs2$topo.summary # A summary of topology
temp.com1vs2$identical # Main results

# (see help of the functions for a comprehensive understanding)
# Finally you could remove the temp objects created
rm(temp.den1, temp.den2, temp.to1, temp.to2, temp.com1vs2)  
}
