\name{analyze.set}
\alias{analyze.set}
\title{
Analyzes all pairs of components of a list of sets
}
\description{
If the length of a list of sets is \code{L}, the number of different pairs sets to be compared will be \code{L*(L-1)/2}. 
For each one those comparisons, results are obtained about the number of elements in each set, the number of elements in the union the number of elements in the intersection as well as a description of the comparison.
}
\usage{
analyze.set(x = test.set)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{
A \code{list} of sets that you want to compare by pairs
}
}
\value{
A \code{data.frame} in which each row contain a different comparison between two of the sets included in the input list of sets \code{x}.
The output is a \code{data.frame} with variables:
\code{id.1} - Numerical identifier of the first set to be compared;
\code{id.2} - Numerical identifier of the second set to be compared;
\code{n.1} - Number of elements in set \code{id.1};
\code{n.2} - Number of elements in set \code{id.2};
\code{n.int} - Number of elements in the intersection of set \code{id.1} with set \code{id.2};
\code{n.uni} - Number of elements in the union of set \code{id.1} with set \code{id.2};
\code{comparison} - A description of the relation between the set \code{id.1} with set \code{id.2}. That \code{comparison} can take values: 
\code{disjoint} - when set \code{id.1} and set \code{id.2} intersection is empty, or, 
\code{identical} - when set \code{id.1} and set \code{id.2} are identical, i.e., have the same elements, or,
\code{s1.includes.s2} - when set \code{id.1} includes all elements in set \code{id.2}, i.e., set \code{id.2} is a proper subset of set \code{id.1}, or, 
\code{s2.includes.s1} - when set \code{id.2} includes all elements in set \code{id.1}, i.e., set \code{id.1} is a proper subset of set \code{id.2}, or, finally, 
\code{intersected} - when set \code{id.1} and set \code{id.2} have a non empty intersection and do not fulfill any of the above classifications. 
\code{s.1} - The explicit set \code{id.1} and 
\code{s.2} - The explicit set \code{id.2}.
}
\author{
Octavio Martinez
}
\seealso{
	\code{\link{test.set}}, \code{\link{analyze2sets}}
}
\examples{
# Make available the default input: a list of 5 sets:
data(test.set)

length(test.set) # How many sets are in the list?
# Define a temporal object from the output of the function
temp.as <- analyze.set(x=test.set)

# Note that the output has 5*(5-1)/2 rows, one for each comparison
nrow(temp.as)

# Let's see the first row which compares the first and second
# elements of test.set,
temp.as[1,]
# Note that even when the two sets, s.1 and s.2 are in different
# order they are the same set.

# Now, let's tabulate the comparisons:
table(temp.as$comparison)

# And see, in turn, each one of the rows with each comparison:
temp.as[temp.as$comparison=="identical",]
temp.as[temp.as$comparison=="disjoint",]
temp.as[temp.as$comparison=="s1.includes.s2",]
temp.as[temp.as$comparison=="s2.includes.s1",]
temp.as[temp.as$comparison=="intersected",]

# Remove the temporal object
rm(temp.as)
}
