\name{analyze2sets}
\alias{analyze2sets}
\title{
Analyzes all pairs of components of two lists of sets
}
\description{
If the length of the first list of sets is \code{L1}, and the length of the second list of sets is \code{L2}, then the number of pairs of sets to be compared will be \code{L1*L2}. 
For each one those comparisons, results are obtained about the number of elements in each set, the number of elements in the union, the number of elements in the intersection as well as a description of the comparison.
}
\usage{
analyze2sets(x = test.set[1:3], y = test.set[2:5], only.identical = FALSE)
}
\arguments{
  \item{x}{
The first \code{list} of sets that you want to compare by pairs
}
  \item{y}{
The second \code{list} of sets that you want to compare by pairs
}
  \item{only.identical}{
A \code{logical} variable. If \code{TRUE} the output will contain only identical sets between the two lists
}
}
\value{
A \code{data.frame} in which each row contain a comparison between two of the sets included in the input lists of sets, \code{x} and \code{y}.
The output \code{data.frame} has variables:
\code{id.x} - Numerical identifier of the set in \code{x} to be compared;
\code{id.y} - Numerical identifier of the set in \code{y} to be compared;
\code{n.x} - Number of elements in set \code{id.x};
\code{n.y} - Number of elements in set \code{id.y};
\code{n.int} - Number of elements in the intersection of set \code{id.x} with set \code{id.x};
\code{n.uni} - Number of elements in the union of set \code{id.x} with set \code{id.x};
\code{comparison} - A description of the relation between the set \code{id.x} with set \code{id.y}. That \code{comparison} can take values: 
\code{disjoint} - when set \code{id.x} and set \code{id.y} intersection is empty, or, 
\code{identical} - when set \code{id.x} and set \code{id.y} are identical, i.e., have the same elements, or,
\code{sx.includes.sy} - when set \code{id.x} includes all elements in set \code{id.y}, i.e., set \code{id.y} is a proper subset of set \code{id.x}, or, 
\code{sy.includes.sx} - when set \code{id.y} includes all elements in set \code{id.x}, i.e., set \code{id.x} is a proper subset of set \code{id.y}, or, finally, 
\code{intersected} - when set \code{id.x} and set \code{id.y} have a non empty intersection and do not fulfill any of the above classifications. 
\code{s.x} - The explicit set \code{id.x} and 
\code{s.y} - The explicit set \code{id.y}.
}
\author{
Octavio Martinez
}
\seealso{
	\code{\link{test.set}}, \code{\link{analyze.set}}
}
\examples{
# Make available the default input: a list of 5 sets:
data(test.set)

# Define a temporal object from the output of the function
# (with defaults)
temp.a2s <- analyze2sets(x = test.set[1:3], y = test.set[2:5])

# Given that x has 3 sets while y has 4 sets we must have
# 3*4=12 rows in the result temp.a2s,
nrow(temp.a2s)

# Let's see the first row:
temp.a2s[1,]

# Now, let's tabulate the comparisons:
table(temp.a2s$comparison)

# And see, in turn, each one of the rows with each comparison:
temp.a2s[temp.a2s$comparison=="identical",]
temp.a2s[temp.a2s$comparison=="disjoint",]
temp.a2s[temp.a2s$comparison=="sx.includes.sy",]
temp.a2s[temp.a2s$comparison=="sy.includes.sx",]
temp.a2s[temp.a2s$comparison=="intersected",]

# Also see the output of the function when only
# identical comparisons are requested
# (note that x & y are let at their default values)
analyze2sets(only.identical=TRUE)

# Remove the temporal object
rm(temp.a2s)
}
