\name{comp.dend}
\alias{comp.dend}
\title{
Compares the topologies of two dendrograms
}
\description{
Assume that you have two dendrograms obtained from the function \code{hclust()}. Using the function \code{dend.topo()} you can obtain the topologies of each one of the two dendrograms. Then, function \code{comp.dend()} will compare the topologies of the two dendrograms, giving likeness estimates as well as an explicit description of the clusters shared by the two dendrograms. This function is the core of the package.
}
\usage{
comp.dend(x = dend.topo(hclust(dist(matrix(c(1:50)/10, nrow = 10, ncol = 5, dimnames = list(LETTERS[1:10], c(1:5)))))), y = dend.topo(hclust(dist(matrix(c(1:50)/9, nrow = 10, ncol = 5, dimnames = list(LETTERS[1:10], c(1:5)))))), compare.groups = FALSE)
}
\arguments{
  \item{x}{
A result of function \code{dend.topo()} containing the description of the topology of the first dendrogram, say dendrogram \code{x}
}
  \item{y}{
A result of function \code{dend.topo()} containing the description of the topology of the second dendrogram, say dendrogram \code{y}
}
  \item{compare.groups}{
A \code{logical} variable which by default is \code{FALSE}. However, if \code{compare.groups = TRUE}, then the output of \code{comp.dend()} will include the description of all possible comparisons between pairs of clusters in both dendrograms. In that case function \code{analyze2sets()} will be used to obtain those comparisons
}
}
\value{
\item{basic }{A \code{numeric} vector with values for variables \code{n.comp} - The number of comparable clusters in the two dendrograms, \code{n.ident} - The number of identical clusters in the two dendrograms,  \code{likeness} - Raw likeness between dendrograms, say \code{n.ident/n.comp} and \code{w.likeness} - The weighted likeness between dendrograms}
\item{topo.summary }{A \code{matrix} with 4 rows and columns with the number of clusters of each length (number of elements) that exist in dendrograms \code{x} or \code{y}. The names of the rows are: \code{n.in.x} - The number of clusters (of each length) in the first dendrogram, \code{n.in.y} - The number of clusters (of each length) in the second dendrogram, \code{n.ident} - The number of clusters (of each length) which are identical in both dendrograms, and \code{p.ident} - The proportion of identity (for each length), say, \code{n.ident} divided by the maximum of \code{n.in.x} and \code{n.in.y} in each one of the columns}
\item{identical }{A \code{data.frame} with information about the clusters that are identical in both dendrograms. The variables in that \code{data.frame} are: \code{id} - Numeric identifier of the cluster comparison, \code{class} - The length (number of elements) in both clusters compared, \code{id.x} - Numeric identifier of the cluster in the first dendrogram, \code{id.y} - Numeric identifier of the cluster in the second dendrogram, \code{height.x} - The height at which cluster \code{id.x} was formed in the first dendrogram, \code{height.y} -  The height at which cluster \code{id.y} was formed in the second dendrogram \code{cluster} - A description of the common cluster in both dendrograms (in set notation and using the labels of the entities)}
\item{height.stats }{A \code{matrix} containing statistics for the heights of the clusters in both dendrograms. The rows of the \code{matrix} are named as \code{All} - Corresponding to statistics for all heights, and \code{Identical} - Corresponding to statistics only for heights in identical clusters. The columns of the \code{matrix} are: \code{n} - The number of heights included, \code{Mean.x} - Average of heights in the first dendrogram, \code{Mean.y} - Average of heights in the second dendrogram, \code{S.x} - Standard deviation of heights in the first dendrogram, \code{S.y} -  Standard deviation of heights in the second dendrogram and \code{p.value} - The value of \code{p} from the \code{t.test} for the means of heights in the first and second dendrograms (not paired test for \code{All} and paired test for \code{Identical})}
\item{clusters.comparison }{A \code{data.frame} which will be present only when the input option \code{compare.groups = TRUE} was used. In that case you need to see the help for function \code{analyze2sets()} for the content of the \code{data.frame}}
\item{objects }{A \code{character} string with descriptions of the inputs \code{x} and \code{y} to the function, extracted from the \code{call} of the function}
\item{call }{The \code{call} of the function}
}
\author{
Octavio Martinez
}
\seealso{
\code{\link{dend.topo}}, \code{\link{analyze2sets}}
}
\examples{
# Let's obtain an object with the defaults of the function
temp.cd <- comp.dend()

# NOTE: for fully understand the output it will be useful if
# you plot and examine the two dendrograms that are being analyzed.
# dendrogram "x" (in the input of the function) can be plot with
# plot(hclust(dist(matrix(c(1:50)/10, nrow = 10, ncol = 5, 
# dimnames = list(LETTERS[1:10], c(1:5))))))
# (to plot x, please input the text after the remarks in the 2 lines above)
# dendrogram "y" (in the input of the function) can be plot with
# plot(hclust(dist(matrix(c(1:50)/9, nrow = 10, ncol = 5, 
# dimnames = list(LETTERS[1:10], c(1:5))))))
# (to plot y, please input the text after the remarks in the 2 lines above)

# Now, lets's examine temp.cd 
class(temp.cd) # Which class is the object?
names(temp.cd) # Which names has each component?

temp.cd # Examine this object

# Now, obtain a second object but with option "compare.groups=TRUE"
temp.cd2 <- comp.dend(compare.groups=TRUE)
# Note that this object has components:
names(temp.cd2)

# The "clusters.comparison" component is a data.frame with
dim(temp.cd2$clusters.comparison)
# and variables:
names(temp.cd2$clusters.comparison)
# Let's see the first 6 rows:
head(temp.cd2$clusters.comparison)
# And also table the comparisons
table(temp.cd2$clusters.comparison$comparison)

# Finally remove the temporary objects
rm(temp.cd, temp.cd2)
}
