\name{dend.topo}
\alias{dend.topo}
\title{
Obtains a description of the topology of a dendrogram
}
\description{
Gives explicit information of all clusters that are present in a dendrogram obtained with the function \code{hclust()} and also a list with an explicit representation of all clusters as sets of labels
}
\usage{
dend.topo(x = hclust(dist(matrix(c(1:50)/10, nrow = 10, ncol = 5, dimnames = list(LETTERS[1:10], c(1:5))))))
}
\arguments{
  \item{x}{
The output of the function \code{hclust()}
}
}
\details{
I recommend to enter the raw output of the function \code{hclust()} (without modifications). Otherwise errors could occur
}
\value{
A list with two components	
\item{original }{A \code{data.frame} with variables
\code{V1} - First numerical identifier of a group in the original dendrogram,
\code{V2} - Second numerical identifier of a group in the original dendrogram,
\code{clu} - Number of cluster within the dendrogram,
\code{class} - Length (number of elements) of the cluster,
\code{height} - Height at which the cluster was formed.
}
\item{clusters }{A \code{list} in which each element is a character variable with the elements of the corresponding cluster}
}
\author{
Octavio Martinez
}
\note{
The elements of the \code{clusters} \code{list} are sets of the original labels in the dendrogram
}
\seealso{
	\code{\link{comp.dend}}
}
\examples{
# Create a temporal object with the output of the function
temp.dt <- dend.topo()

# Note that the default of the function is
# x = hclust(dist(matrix(c(1:50)/10, nrow = 10, ncol = 5, 
#     dimnames = list(LETTERS[1:10], c(1:5)))))
# i.e., a dendrogram obtained from the Euclidean distance of an
# arbitrary matrix. Optionally you could plot such dendrogram
# for a better understanding:
# plot(hclust(dist(matrix(c(1:50)/10, nrow = 10, ncol = 5,
# dimnames = list(LETTERS[1:10], c(1:5))))))

# Note that
class(temp.dt)

# With components
names(temp.dt)

# Now, the first component is a data.frame
temp.dt$original

# And the second a list with all the clusters
temp.dt$clusters

# You could analyze that list of clusters
# for example with
# analize.set(temp.dt$clusters) 
# which gives a data.frame with 36 rows.
# See the last two rows with
# tail(analize.set(temp.dt$clusters), 2)

# Finally remove the temporal object
rm(temp.dt)
}
